aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorFenrir <[email protected]>2019-03-17 18:51:59 -0600
committerFenrirWolf <[email protected]>2019-03-17 19:02:01 -0600
commit48d9199714caf6217ad3c44524d1e371ac5df056 (patch)
tree776bb51560361f305b4f82496c368eb5d0b66dfc
parentMerge pull request #74 from FenrirWolf/gfx (diff)
downloadctru-rs-48d9199714caf6217ad3c44524d1e371ac5df056.tar.xz
ctru-rs-48d9199714caf6217ad3c44524d1e371ac5df056.zip
QUERTY -> QWERTY
-rw-r--r--ctru-rs/src/applets/swkbd.rs6
1 files changed, 3 insertions, 3 deletions
diff --git a/ctru-rs/src/applets/swkbd.rs b/ctru-rs/src/applets/swkbd.rs
index 515dd92..dc84d1b 100644
--- a/ctru-rs/src/applets/swkbd.rs
+++ b/ctru-rs/src/applets/swkbd.rs
@@ -14,8 +14,8 @@ pub struct Swkbd {
/// The kind of keyboard to be initialized.
///
/// Normal is the full keyboard with several pages (QUERTY/accents/symbol/mobile)
/// Querty is a QUERTY-only keyboard.
/// Numpad is a number pad.
/// Western is a text keyboard without japanese symbols (only applies to JPN systems). For other
/// systems it's the same as a Normal keyboard.
@@ -69,7 +69,7 @@ bitflags! {
const ALLOW_HOME = 1 << 5;
const ALLOW_RESET = 1 << 6;
const ALLOW_POWER = 1 << 7;
- const DEFAULT_QUERTY = 1 << 8;
+ const DEFAULT_QWERTY = 1 << 8;
}
}
@@ -14,8 +14,8 @@ pub struct Swkbd {
/// The kind of keyboard to be initialized.
///
-/// Normal is the full keyboard with several pages (QUERTY/accents/symbol/mobile)
-/// Querty is a QUERTY-only keyboard.
+/// Normal is the full keyboard with several pages (QWERTY/accents/symbol/mobile)
+/// Querty is a QWERTY-only keyboard.
/// Numpad is a number pad.
/// Western is a text keyboard without japanese symbols (only applies to JPN systems). For other